==> mcservercreator-1.0.1.tar.gz: mcservercreator-1.0.1/mcservercreator/constants.py <==
FULL_NAME = 'Minecraft Server Creator'
SHORT_NAME = 'MCSC'
PACKAGE_NAME = 'mcservercreator'
DESCRIPTION = 'A tool to help you create and manage minecraft servers easier'
AUTHOR = 'Ivan1F'
VERSION = '1.0.1'
GITHUB_REPO = 'https://github.com/Ivan1F/MinecraftServerCreator'

VERSION_API = 'https://launchermeta.mojang.com/mc/game/version_manifest.json'
FABRIC_URL = 'https://maven.fabricmc.net/net/fabricmc/fabric-installer/0.7.3/fabric-installer-0.7.3.jar'

DEFAULT_SERVER_PROPERTIES = '''spawn-protection=16
max-tick-time=60000
query.port=25565
generator-settings=
sync-chunk-writes=true
force-gamemode=false
allow-nether=true
enforce-whitelist=false
gamemode=survival
broadcast-console-to-ops=true
enable-query=false
player-idle-timeout=0
text-filtering-config=
difficulty=easy
broadcast-rcon-to-ops=true
spawn-monsters=true
op-permission-level=4
pvp=true
entity-broadcast-range-percentage=100
snooper-enabled=true
level-type=default
enable-status=true
resource-pack-prompt=
hardcore=false
enable-command-block=false
network-compression-threshold=256
max-players=20
max-world-size=29999984
resource-pack-sha1=
function-permission-level=2
rcon.port=25575
server-port=25565
server-ip=
spawn-npcs=true
require-resource-pack=false
allow-flight=false
level-name=world
view-distance=10
resource-pack=
spawn-animals=true
white-list=false
rcon.password=
generate-structures=true
online-mode=true
level-seed=
prevent-proxy-connections=false
use-native-transport=true
enable-jmx-monitoring=false
motd=A Minecraft Server
rate-limit=0
enable-rcon=false
'''

==> mcservercreator-1.0.2.tar.gz: mcservercreator-1.0.2/mcservercreator/constants.py <==
FULL_NAME = 'Minecraft Server Creator'
SHORT_NAME = 'MCSC'
PACKAGE_NAME = 'mcservercreator'
DESCRIPTION = 'A tool to help you create and manage minecraft servers easier'
AUTHOR = 'Ivan1F'
VERSION = '1.0.2'
GITHUB_REPO = 'https://github.com/Ivan-1F/Minecraft-Server-Creator'

VERSION_API = 'https://launchermeta.mojang.com/mc/game/version_manifest.json'
FABRIC_URL = 'https://maven.fabricmc.net/net/fabricmc/fabric-installer/0.7.3/fabric-installer-0.7.3.jar'

DEFAULT_SERVER_PROPERTIES = '''spawn-protection=16
max-tick-time=60000
query.port=25565
generator-settings=
sync-chunk-writes=true
force-gamemode=false
allow-nether=true
enforce-whitelist=false
gamemode=survival
broadcast-console-to-ops=true
enable-query=false
player-idle-timeout=0
text-filtering-config=
difficulty=easy
broadcast-rcon-to-ops=true
spawn-monsters=true
op-permission-level=4
pvp=true
entity-broadcast-range-percentage=100
snooper-enabled=true
level-type=default
enable-status=true
resource-pack-prompt=
hardcore=false
enable-command-block=false
network-compression-threshold=256
max-players=20
max-world-size=29999984
resource-pack-sha1=
function-permission-level=2
rcon.port=25575
server-port=25565
server-ip=
spawn-npcs=true
require-resource-pack=false
allow-flight=false
level-name=world
view-distance=10
resource-pack=
spawn-animals=true
white-list=false
rcon.password=
generate-structures=true
online-mode=true
level-seed=
prevent-proxy-connections=false
use-native-transport=true
enable-jmx-monitoring=false
motd=A Minecraft Server
rate-limit=0
enable-rcon=false
'''
